==> arrow-docs-0.8.0-sources.jar: arrow/optics/Street$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Street`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Street`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Iso(
  get = { street: `arrow`.`optics`.`Street` -> arrow.core.Tuple2(street.`number`, street.`name`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`> -> `arrow`.`optics`.`Street`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Street`.Companion.number: arrow.optics.Lens<`arrow`.`optics`.`Street`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { street: `arrow`.`optics`.`Street` -> street.`number` },
  set = { value: `kotlin`.`Int` ->
    { street: `arrow`.`optics`.`Street` ->
      street.copy(`number` = value)
    }
  }
)

inline val `arrow`.`optics`.`Street`.Companion.name: arrow.optics.Lens<`arrow`.`optics`.`Street`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { street: `arrow`.`optics`.`Street` -> street.`name` },
  set = { value: `kotlin`.`String` ->
    { street: `arrow`.`optics`.`Street` ->
      street.copy(`name` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name

==> arrow-docs-0.10.3-sources.jar: arrow/optics/Street$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Street`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Street`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Iso(
  get = { street: `arrow`.`optics`.`Street` -> arrow.core.Tuple2(street.`number`, street.`name`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`> -> `arrow`.`optics`.`Street`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Street`.Companion.number: arrow.optics.Lens<`arrow`.`optics`.`Street`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { street: `arrow`.`optics`.`Street` -> street.`number` },
  set = { street: `arrow`.`optics`.`Street`, value: `kotlin`.`Int` -> street.copy(`number` = value) }
)

inline val `arrow`.`optics`.`Street`.Companion.name: arrow.optics.Lens<`arrow`.`optics`.`Street`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { street: `arrow`.`optics`.`Street` -> street.`name` },
  set = { street: `arrow`.`optics`.`Street`, value: `kotlin`.`String` -> street.copy(`name` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Street`>.number: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Street`.number

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Street`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Street`.name
